summaryrefslogtreecommitdiff
path: root/tools
diff options
context:
space:
mode:
authorMark McClain <mark.mcclain@dreamhost.com>2013-07-03 19:39:46 -0400
committerMark McClain <mark.mcclain@dreamhost.com>2013-07-06 15:02:43 -0400
commitee3fe4e836ca1c81e50a8324a9b5f982de4fa97f (patch)
treeedf9fb0d3c797c4db68ab7c47944589a9652ec5a /tools
parentfc52854c1f9f58421839115cbf1204c9e8ec4034 (diff)
downloadneutron-ee3fe4e836ca1c81e50a8324a9b5f982de4fa97f.tar.gz
Rename Quantum to Neutron
This change renames everything to Neutron while providing backwards compatible adjustments for Grizzly configuration files. implements blueprint: remove-use-of-quantum Change-Id: Ie7d07ba7c89857e13d4ddc8f0e9b68de020a3d19
Diffstat (limited to 'tools')
-rwxr-xr-xtools/clean.sh2
-rw-r--r--tools/i18n_cfg.py4
-rw-r--r--tools/install_venv.py10
-rw-r--r--tools/patch_tox_venv.py2
4 files changed, 9 insertions, 9 deletions
diff --git a/tools/clean.sh b/tools/clean.sh
index c1deb844c6..27bc219f9c 100755
--- a/tools/clean.sh
+++ b/tools/clean.sh
@@ -2,4 +2,4 @@
rm -rf ./*.deb ./*.tar.gz ./*.dsc ./*.changes
rm -rf */*.deb
rm -rf ./plugins/**/build/ ./plugins/**/dist
-rm -rf ./plugins/**/lib/quantum_*_plugin.egg-info ./plugins/quantum-*
+rm -rf ./plugins/**/lib/neutron_*_plugin.egg-info ./plugins/neutron-*
diff --git a/tools/i18n_cfg.py b/tools/i18n_cfg.py
index 9cd87acc3d..abc1bfb14a 100644
--- a/tools/i18n_cfg.py
+++ b/tools/i18n_cfg.py
@@ -92,6 +92,6 @@ msg_format_checkers = [
]
-file_black_list = ["./quantum/tests/unit",
- "./quantum/openstack",
+file_black_list = ["./neutron/tests/unit",
+ "./neutron/openstack",
"./quantum/plugins/bigswitch/tests"]
diff --git a/tools/patch_tox_venv.py b/tools/patch_tox_venv.py
index 16e4accdd5..a3cb46aaf1 100644
--- a/tools/patch_tox_venv.py
+++ b/tools/patch_tox_venv.py
@@ -40,7 +40,7 @@ def main(argv):
os.path.join(root, 'tools', 'test-requires'),
])
py_version = "python%s.%s" % (sys.version_info[0], sys.version_info[1])
- project = 'quantum'
+ project = 'neutron'
install = install_venv.InstallVenv(root, venv, pip_requires, test_requires,
py_version, project)
#NOTE(dprince): For Tox we only run post_process (which patches files, etc)
diff --git a/tools/install_venv.py b/tools/install_venv.py
index eda0ced903..a51c29512e 100644
--- a/tools/install_venv.py
+++ b/tools/install_venv.py
@@ -21,7 +21,7 @@
# under the License.
"""
-Installation script for Quantum's development virtualenv
+Installation script for Neutron's development virtualenv
"""
import os
@@ -33,12 +33,12 @@ import install_venv_common as install_venv
def print_help():
help = """
Quantum development environment setup is complete.
Quantum development uses virtualenv to track and manage Python dependencies
while in development and testing.
To activate the Quantum virtualenv for the extent of your current shell
session you can run:
$ source .venv/bin/activate
@@ -59,7 +59,7 @@ def main(argv):
pip_requires = os.path.join(root, 'requirements.txt')
test_requires = os.path.join(root, 'test-requirements.txt')
py_version = "python%s.%s" % (sys.version_info[0], sys.version_info[1])
- project = 'Quantum'
+ project = 'Neutron'
install = install_venv.InstallVenv(root, venv, pip_requires, test_requires,
py_version, project)
options = install.parse_args(argv)
@@ -33,12 +33,12 @@ import install_venv_common as install_venv
def print_help():
help = """
- Quantum development environment setup is complete.
+ Neutron development environment setup is complete.
- Quantum development uses virtualenv to track and manage Python dependencies
+ Neutron development uses virtualenv to track and manage Python dependencies
while in development and testing.
@@ -33,12 +33,12 @@ import install_venv_common as install_venv
while in development and testing.
- To activate the Quantum virtualenv for the extent of your current shell
+ To activate the Neutron virtualenv for the extent of your current shell
session you can run:
$ source .venv/bin/activate